#!/usr/bin/env python

"""Take time lapse photos from a webcam"""

__author__ = "Ryan McGuire <enigmacurry.com>"

from camera import Camera
from PIL import Image
import time
import os

def mkdir(newdir):
    """works the way a good mkdir should :)
        - already exists, silently complete
        - regular file in the way, raise an exception
        - parent directory(ies) does not exist, make them as well
    """
    if os.path.isdir(newdir):
        pass
    elif os.path.isfile(newdir):
        raise OSError("a file with the same name as the desired " \
                      "dir, '%s', already exists." % newdir)
    else:
        head, tail = os.path.split(newdir)
        if head and not os.path.isdir(head):
            mkdir(head)
        if tail:
            os.mkdir(newdir)

if __name__ == "__main__":
    from optparse import OptionParser
    parser = OptionParser(version="%prog 1.0",usage="%prog [options]", description="Periodically saves frames from a v4l2 device")
    parser.add_option("-f","--frequency",dest="frequency",
                      help="Frequency to grab frames in seconds", default="5")
    parser.add_option("-d","--destination-dir",dest="destination_dir",
                      help="Directory to place images in", default="images")
    (options, args) = parser.parse_args()
    
    camera = Camera()

    frequency = int(options.frequency)

    mkdir(options.destination_dir)

    #The first picture taken will probably be garbled due to the camera not being initialized.
    #Take a throw away picture
    print "Initializing.."
    camera.takePicture()
    time.sleep(3)
    
    while(True):
        data = camera.takePicture()[0].data
        filename = os.path.join(options.destination_dir,"%s.jpg" % time.strftime("%Y-%m-%d--%H:%M:%S",time.localtime()))
        Image.fromstring("RGB", (camera.width,camera.height), data).save(filename,"JPEG")
        print("saved %s" % filename)
        time.sleep(frequency)
        
